#!/bin/bash
#PBS -l walltime=01:00:00
#PBS -l ncpus=1,mem=2gb
#PBS -q uv2000
#PBS -N gather_results
#PBS -j oe



### folder structure for the downstream analysis - created by NHS_WES_trio_setup.sh ###
BASE=/scratch/u027/project/trio_whole_exome/analysis
WORK_DIR=${BASE}/${PROJECT_ID}
NHS_DIR=${WORK_DIR}/${PLATE_ID}_results


# other files to be used
FAMILY_IDS=${WORK_DIR}/FAM_IDs.txt                                                      # created by NHS_WES_trio_setup.sh
CHILD_IDS=${WORK_DIR}/PRO_IDs.txt                                                       # created by NHS_WES_trio_setup.sh


echo "PLATE_ID = ${PLATE_ID}"           # the PCR plate ID of the batch being currently processed,              	e.g. 16862
echo "PROJECT_ID = ${PROJECT_ID}"       # this the the folder (${BASE}/${PROJECT_ID}) where the downstream analysis will be done


# check if ${NHS_DIR} already exists - if not, exit and ask to be created
if [ ! -d "${NHS_DIR}" ]; then
  echo "${NHS_DIR} does not exist - need to create it before running this script!!!!"
  exit
fi




FAMILY_ID=`head -n ${PBS_ARRAY_INDEX} ${FAMILY_IDS} | tail -n 1`				# contains only the family IDs (e.g.385295)
PROBAND_ID=`head -n ${PBS_ARRAY_INDEX} ${CHILD_IDS} | tail -n 1`				# contains only the proband IDs (e.g. 107060)


# create the family folder for the results
FAM_DIR=${NHS_DIR}/${PLATE_ID}_${FAMILY_ID}
mkdir ${FAM_DIR}


# copy the VASE de novo variants in the proband VCF file
cp ${WORK_DIR}/VASE/${PLATE_ID}_${FAMILY_ID}.ready.denovo.vcf ${FAM_DIR}


# copy the DECIPHER-to-INTERNAL ID mapping
cp ${WORK_DIR}/DECIPHER_INTERNAL_IDs.txt ${FAM_DIR}


# copy the LOG file
cp ${WORK_DIR}/LOG/process_trio.o*.${PBS_ARRAY_INDEX} ${FAM_DIR}


# copy the G2P family html report
cp ${WORK_DIR}/G2P/${PLATE_ID}_${FAMILY_ID}_LOG_DIR/${PLATE_ID}_${FAMILY_ID}.report.html ${FAM_DIR}


# copy the DECIPHER file for bulk upload
cp ${WORK_DIR}/DECIPHER/${PROBAND_ID}_${FAMILY_ID}_DEC_FLT.csv ${FAM_DIR}


# copy the variant snapshots
cp ${WORK_DIR}/DECIPHER/IGV/${PLATE_ID}_${FAMILY_ID}/*.png ${FAM_DIR}


# copy proband coverage file
cp ${WORK_DIR}/COV/${PROBAND_ID}_${FAMILY_ID}.DD15.COV.txt ${FAM_DIR}


echo "OK: Results for ${FAMILY_ID} are stored in ${FAM_DIR}"

